@@ -75,11 +75,11 @@ class Machine(htb.HTBObject):
 
         Args:
             flag: The flag for the Machine
-            difficulty: A rating between 10 and 100 of the Machine difficulty
-
+            difficulty: A rating between 10 and 100 of the Machine difficulty.
+                        Must be a multiple of 10.
         """
         if difficulty < 10 or difficulty > 100 or difficulty % 10 != 0:
-            raise IncorrectArgumentException
+            raise IncorrectArgumentException(reason="Difficulty must be a multiple of 10, between 10 and 100")
 
         submission = self._client.do_request("machine/own", json_data={
             "flag": flag,
@@ -95,7 +95,7 @@ class Machine(htb.HTBObject):
     def authors(self) -> List["User"]:
         """Fetch the author(s) of the Machine
 
-        Returns: List of User
+        Returns: List of Users
 
         """
         if not self._authors:
@@ -130,8 +130,10 @@ class Machine(htb.HTBObject):
         if not summary:
             self.active = bool(data['active'])
             self.retired = bool(data['retired'])
-            self.user_own_time = parse_delta(data['authUserFirstUserTime'])
-            self.root_own_time = parse_delta(data['authUserFirstRootTime'])
+            if data['authUserInUserOwns']:
+                self.user_own_time = parse_delta(data['authUserFirstUserTime'])
+            if data['authUserInRootOwns']:
+                self.root_own_time = parse_delta(data['authUserFirstRootTime'])
             self.difficulty_ratings = data['feedbackForChart']
             if data['userBlood']:
                 user_blood_data = {
